@@ -19,4 +19,8 @@ sys.modules['Social'] = mod = objc.ObjCLazyModule(
         '__doc__': __doc__,
         'objc': objc,
         '__path__': __path__,
+        '__loader__': globals().get('__loader__', None),
     }, (Foundation,))
+
+import sys
+del sys.modules['Social._metadata']
